==> PricingEngine-0.0.3-beta-.tar.gz: PricingEngine-0.0.3-beta-/setup.py <==
import os
import subprocess
import sys
import glob
import shutil
from distutils.sysconfig import get_python_lib

from setuptools import find_packages, setup

CURRENT_PYTHON = sys.version_info[:2]
REQUIRED_PYTHON = (3, 5)

# This check and everything above must remain compatible with Python 2.7.
if CURRENT_PYTHON < REQUIRED_PYTHON:
    sys.stderr.write("""
==========================
Unsupported Python version
==========================
This version of pricingengine requires Python {}.{}, but you're trying to
install it on Python {}.{}.
This may be because you are using a version of pip that doesn't
understand the python_requires classifier. Make sure you
have pip >= 9.0 and setuptools >= 24.2, then try again:
    $ python -m pip install --upgrade pip setuptools
    $ python -m pip install PricingEngine
This will install the latest version of pricingengine which works on your
version of Python."
""".format(*(REQUIRED_PYTHON + CURRENT_PYTHON)))
    sys.exit(1)

# Warn if we are installing over top of an existing installation. This can
# cause issues where files that were deleted from a more recent Django are
# still present in site-packages. See #18115.
overlay_warning = False
if "install" in sys.argv:
    lib_paths = [get_python_lib()]
    if lib_paths[0].startswith("/usr/lib/"):
        # We have to try also with an explicit prefix of /usr/local in order to
        # catch Debian's custom user site-packages directory.
        lib_paths.append(get_python_lib(prefix="/usr/local"))
    for lib_path in lib_paths:
        existing_path = os.path.abspath(os.path.join(lib_path, "pricingengine"))
        if os.path.exists(existing_path):
            # We note the need for the warning here, but present it after the
            # command is run, so it's more likely to be seen.
            overlay_warning = True
            break

EXCLUDE_FROM_PACKAGES = ['pricingengine.conf.project_template',
                         'pricingengine.conf.app_template',
                         'pricingengine.bin']

# Dynamically calculate the version based on django.VERSION.
# version = __import__('pricingengine').get_version()
version = '0.0.3(beta)'

def read(fname):
    with open(os.path.join(os.path.dirname(__file__), fname)) as f:
        return f.read()

setup(
    name='PricingEngine',
    version=version,
    python_requires='>={}.{}'.format(*REQUIRED_PYTHON),
    url='http://www.smalldaytech.com',
    author='SmallDay',
    author_email='pranjal@smalldaytech.com',
    description=('Predict the the ACV of the used car '
                 'dealer can buy in optimised price to gain maximum profit.'),
    long_description=read('README.md'),
    license='BSD',
    # packages=['mymodule', 'mymodule.subdir'],
    packages=find_packages(exclude=EXCLUDE_FROM_PACKAGES),
    include_package_data=True,
    # scripts=[''],
    entry_points={'console_scripts': [
    ]},
    install_requires=['pytz', 'scikit-learn', 'pybuilder', 'pymysql', 'configparser', 'pytest', 'scipy',
                      'matplotlib', 'numpy', 'pandas', 'seaborn', 'sklearn'],
    extras_require={
        "bcrypt": ["bcrypt"],
        "argon2": ["argon2-cffi >= 16.1.0"],
    },
    zip_safe=False,
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Internet :: WWW/HTTP :: WSGI',
    ],
    # project_urls={
    #     'Documentation': '',
    #     'Funding': '',
    #     'Source': '',
    #     'Tracker': '',
    # },
)
# script_dir = os.path.dirname(os.path.realpath(__file__))
# build_script = os.path.join(script_dir, "build.py")
# exit_code = 0
# try:
#     subprocess.check_call([sys.executable, build_script, "clean", "install_dependencies", "package", "-o"])
#     dist_dir = glob.glob(os.path.join(script_dir, "target", "dist", "*"))[0]
#     for src_file in glob.glob(os.path.join(dist_dir, "*")):
#         file_name = os.path.basename(src_file)
#         target_file_name = os.path.join(script_dir, file_name)
#         if os.path.exists(target_file_name):
#             if os.path.isdir(target_file_name):
#                 shutil.rmtree(target_file_name)
#             else:
#                 os.remove(target_file_name)
#         shutil.move(src_file, script_dir)
#     setup_args = sys.argv[1:]
#     subprocess.check_call([sys.executable, "setup.py"] + setup_args, cwd=script_dir)
# except subprocess.CalledProcessError as e:
#     exit_code = e.returncode
# sys.exit(exit_code)
if overlay_warning:
    sys.stderr.write("""
========
WARNING!
========
You have just installed PricingEngine over top of an existing
installation, without removing it first. Because of this,
your install may now include extraneous files from a
previous version that have since been removed from
PricingEngine. This is known to cause a variety of problems. You
should manually remove the
%(existing_path)s
directory and re-install PricingEngine.
""" % {"existing_path": existing_path})

==> PricingEngine-0.0.5-beta-.tar.gz: PricingEngine-0.0.5-beta-/setup.py <==
import os
import sys
from distutils.sysconfig import get_python_lib

from setuptools import find_packages, setup

CURRENT_PYTHON = sys.version_info[:2]
REQUIRED_PYTHON = (3, 5)

# This check and everything above must remain compatible with Python 2.7.
if CURRENT_PYTHON < REQUIRED_PYTHON:
    sys.stderr.write("""
==========================
Unsupported Python version
==========================
This version of pricingengine requires Python {}.{}, but you're trying to
install it on Python {}.{}.
This may be because you are using a version of pip that doesn't
understand the python_requires classifier. Make sure you
have pip >= 9.0 and setuptools >= 24.2, then try again:
    $ python -m pip install --upgrade pip setuptools
    $ python -m pip install PricingEngine
This will install the latest version of pricingengine which works on your
version of Python."
""".format(*(REQUIRED_PYTHON + CURRENT_PYTHON)))
    sys.exit(1)
existing_path = ''
# Warn if we are installing over top of an existing installation. This can
# cause issues where files that were deleted from a more recent Django are
# still present in site-packages. See #18115.
overlay_warning = False
if "install" in sys.argv:
    lib_paths = [get_python_lib()]
    if lib_paths[0].startswith("/usr/lib/"):
        # We have to try also with an explicit prefix of /usr/local in order to
        # catch Debian's custom user site-packages directory.
        lib_paths.append(get_python_lib(prefix="/usr/local"))
    for lib_path in lib_paths:
        existing_path = os.path.abspath(os.path.join(lib_path, "pricingengine"))
        if os.path.exists(existing_path):
            # We note the need for the warning here, but present it after the
            # command is run, so it's more likely to be seen.
            overlay_warning = True
            break

EXCLUDE_FROM_PACKAGES = ['pricingengine.conf.project_template',
                         'pricingengine.conf.app_template',
                         'pricingengine.bin']

# Dynamically calculate the version based on django.VERSION.
# version = __import__('pricingengine').get_version()
version = '0.0.5(beta)'


def read(fname):
    with open(os.path.join(os.path.dirname(__file__), fname)) as f:
        return f.read()


setup(
    name='PricingEngine',
    version=version,
    python_requires='>={}.{}'.format(*REQUIRED_PYTHON),
    url='http://www.smalldaytech.com',
    author='SmallDay',
    author_email='pranjal@smalldaytech.com',
    description=('Predict the the ACV of the used car '
                 'dealer can buy in optimised price to gain maximum profit.'),
    long_description=read('README.md'),
    license='BSD',
    # packages=['mymodule', 'mymodule.subdir'],
    packages=find_packages(exclude=EXCLUDE_FROM_PACKAGES),
    include_package_data=True,
    # scripts=[''],
    entry_points={'console_scripts': [
    ]},
    install_requires=['pytz', 'scikit-learn', 'pybuilder', 'pymysql', 'configparser', 'pytest', 'scipy',
                      'matplotlib', 'numpy', 'pandas', 'seaborn', 'sklearn', 'requests', 'tornado', 'sqlalchemy',
                      'xgboost', 'pymysql_manager'],
    extras_require={
        "bcrypt": ["bcrypt"],
        "argon2": ["argon2-cffi >= 16.1.0"],
    },
    zip_safe=False,
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Internet :: WWW/HTTP :: WSGI',
    ],
    # project_urls={
    #     'Documentation': '',
    #     'Funding': '',
    #     'source': '',
    #     'Tracker': '',
    # },
)

if overlay_warning:
    sys.stderr.write("""
========
WARNING!
========
You have just installed PricingEngine over top of an existing
installation, without removing it first. Because of this,
your install may now include extraneous files from a
previous version that have since been removed from
PricingEngine. This is known to cause a variety of problems. You
should manually remove the
%(existing_path)s
directory and re-install PricingEngine.
""" % {"existing_path": existing_path})
